import argparse
import owo

parser = argparse.ArgumentParser()
parser.add_argument("key", help="Your API key")
parser.add_argument("target", help="File to upload/URL to shorten")
parser.add_argument("-v", "--verbose", help="Return all domains",
                    action="store_true", default=False)
group = parser.add_mutually_exclusive_group()
group.add_argument("--upload", help="Upload a file", action="store_true")
group.add_argument("--shorten", help="Shorten a URL", action="store_true")

args = parser.parse_args()

if args.upload:
    res = owo.upload_files(args.key, args.target, verbose=args.verbose)
    print(res[args.target])

elif args.shorten:
    res = owo.shorten_urls(args.key, args.target, verbose=args.verbose)
    print(res[0])

else:
    parser.error("Either --upload or --shorten should be given")



#!/usr/bin/env python3.5

from __future__ import print_function

import argparse
import owo


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("key", help="Your API key")
    parser.add_argument("target", help="File to upload/URL to shorten")
    parser.add_argument("-v", "--verbose", help="Return all domains",
                        action="store_true", default=False)
    group = parser.add_mutually_exclusive_group()
    group.add_argument("--upload", help="Upload a file", action="store_true")
    group.add_argument("--shorten", help="Shorten a URL", action="store_true")

    args = parser.parse_args()

    if args.upload:
        res = owo.upload_files(args.key, args.target, verbose=args.verbose)
        print(res[args.target.lower()])

    elif args.shorten:
        res = owo.shorten_urls(args.key, args.target, verbose=args.verbose)
        print(res[0])

    else:
        parser.error("Either --upload or --shorten should be given")


if __name__ == '__main__':
    main()



import os.path
import re

DOMAINS_URL = "https://raw.githubusercontent.com/whats-this/landing/master/public-cdn-domains.txt"

import requests
resp = requests.get(DOMAINS_URL)
content = resp.text

MAX_FILES = 3

BASE_URL = "https://api.awau.moe"

UPLOAD_PATH = "/upload/pomf"
SHORTEN_PATH = "/shorten/polr"

UPLOAD_STANDARD = "https://owo.whats-th.is/"
SHORTEN_STANDARD = "https://uwu.whats-th.is/"

UPLOAD_BASES = ["https://{}/".format(url) for url in re.findall("files:(.+)", content)]

SHORTEN_BASES = ["https://{}/".format(url) for url in re.findall("link:(.+)", content)]


def check_size(file):
    if os.path.getsize(file) > 83886080:
        raise OverflowError("File exceeds file size limit")



import asyncio
from functools import lru_cache

from .utils import check_size, BASE_URL, MAX_FILES,\
    UPLOAD_PATH, SHORTEN_PATH, UPLOAD_STANDARD,\
    SHORTEN_STANDARD, UPLOAD_BASES, SHORTEN_BASES


@lru_cache(maxsize=None)
@asyncio.coroutine
def async_upload_files(key, *files, **kwargs):
    verbose = kwargs.get("verbose", False)
    loop = kwargs.get("loop", None)
    if len(files) > MAX_FILES:
        raise OverflowError("Maximum amout of files to send at once"
                            "is {}".format(MAX_FILES))

    try:
        from . import aiohttp2
        import aiohttp
    except ImportError:
        raise ImportError("Please install the `aiohttp` module "
                          "to use this function")

    results = {}

    for file in files:
        check_size(file)

    with aiohttp2.MultipartWriter('form-data') as mp:
        for file in files:
            part = mp.append(open(file, "rb"))
            part.set_content_disposition(
                'form-data',
                should_quote=False,
                name='files[]',
                filename=file.lower()
            )

        with aiohttp.ClientSession(loop=loop) as session:
            with (
                yield from session.post(BASE_URL+UPLOAD_PATH, data=mp,
                                        params={"key": key})) as response:
                if response.status != 200:
                    raise ValueError("Expected 200, got {}\n{}".format(
                        response.status, (yield from response.text())))

                for item in (yield from response.json())["files"]:
                    if item.get("error") is True:
                        raise ValueError("Expected 200, got {}\n{}".format(
                            item["errorcode"], item["description"]))

                    if verbose:
                        results[item["name"]] = {
                            base: base+item["url"]
                            for base in UPLOAD_BASES
                        }

                    else:
                        results[item["name"]] = UPLOAD_STANDARD+item["url"]

    return results


@lru_cache(maxsize=None)
@asyncio.coroutine
def async_shorten_urls(key, *urls, **kwargs):
    verbose = kwargs.get("verbose", False)
    loop = kwargs.get("loop", None)
    try:
        import aiohttp
    except ImportError:
        raise ImportError("Please install the `aiohttp` module "
                          "to use this function")

    results = []

    with aiohttp.ClientSession(loop=loop) as session:
        for url in urls:
            with (
                yield from session.get(BASE_URL+SHORTEN_PATH,
                                       params={"action": "shorten",
                                               "url": url,
                                               "key": key})) as response:
                if response.status != 200:
                    raise ValueError("Expected 200, got {}\n{}".format(
                        response.status, (yield from response.text())))

            path = (yield from response.text()).split("/")[-1]
            if verbose:
                results.append({
                    base: base+path
                    for base in SHORTEN_BASES
                })
            else:
                results.append(SHORTEN_STANDARD + path)

    return results


class Client:
    @asyncio.coroutine
    def async_upload_files(self, *files):
        return async_upload_files(self.key, *files,
                                  loop=self.loop, verbose=self.verbose)

    @asyncio.coroutine
    def async_shorten_urls(self, *urls):
        return async_shorten_urls(self.key, *urls,
                                  loop=self.loop, verbose=self.verbose)



# This here is purely to override aiohttp's quoting system
# because it's shit and PR #916 has been open for about a year
# Thanks to Leovoel for helping me with this

from aiohttp.multipart import TOKEN
from aiohttp.hdrs import CONTENT_DISPOSITION
from urllib.parse import quote

import aiohttp


class BodyPartWriter(aiohttp.BodyPartWriter):
    def set_content_disposition(self, disposition_type,
                                should_quote=True, **params):
        if not disposition_type or not (TOKEN > set(disposition_type)):
            raise ValueError('bad content disposition type '
                             '{!r}'.format(disposition_type))
        value = disposition_type
        if params:
            lparams = []
            for key, val in params.items():
                if not key or not (TOKEN > set(key)):
                    raise ValueError('bad content disposition parameter '
                                     '{!r}={!r}'.format(key, val))
                qval = quote(val, '') if should_quote else val
                lparams.append((key, '"%s"' % qval))
                if key == 'filename':
                    lparams.append(('filename*', "utf-8''" + qval))
            value = '; '.join((value, '; '.join('='.join(pair)
                                                for pair in lparams)))
        self.headers[CONTENT_DISPOSITION] = value


class MultipartWriter(aiohttp.MultipartWriter):
    part_writer_cls = BodyPartWriter



import mimetypes
import sys

try:
    from functools import lru_cache
except ImportError:
    # python 2 doesnt have lru_cache
    # Create a dummy wrapper instead

    def lru_cache(maxsize=None):
        def wrapper(func):
            def inner(*args, **kwargs):
                return func(*args, **kwargs)
            return inner
        return wrapper

from .utils import check_size, BASE_URL, MAX_FILES,\
    UPLOAD_PATH, SHORTEN_PATH, UPLOAD_STANDARD,\
    SHORTEN_STANDARD, UPLOAD_BASES, SHORTEN_BASES

PY_VERSION = sys.version_info.major

if PY_VERSION == 3:
    __all__ = ["upload_files", "shorten_urls",
               "async_upload_files", "async_shorten_urls",
               "Client"]
else:
    __all__ = ["upload_files", "shorten_urls",
               "Client"]


@lru_cache(maxsize=None)
def upload_files(key, *files, **kwargs):
    verbose = kwargs.get("verbose", False)
    if len(files) > MAX_FILES:
        raise OverflowError("Maximum amout of files to send at once"
                            "is {}".format(MAX_FILES))

    try:
        import requests
    except ImportError:
        raise ImportError("Please install the `requests` module "
                          "to use this function")

    for file in files:
        check_size(file)

    multipart = [(
        "files[]",
        (
            file.lower(),
            open(file, "rb"),
            mimetypes.guess_type(file)[0]
        ))
        for file in files]

    response = requests.post(BASE_URL+UPLOAD_PATH, files=multipart,
                             params={"key": key})

    if response.status_code != 200:
        raise ValueError("Expected 200, got {}\n{}".format(
            response.status_code, response.text))

    if verbose:
        results = {
            item["name"]: {
                base: base+item["url"]
                for base in UPLOAD_BASES
            }
            for item in response.json()["files"]
        }

    else:
        results = {
            item["name"]: UPLOAD_STANDARD + item["url"]
            for item in response.json()["files"]
        }

    return results


@lru_cache(maxsize=None)
def shorten_urls(key, *urls, **kwargs):
    verbose = kwargs.get("verbose", False)
    try:
        import requests
    except ImportError:
        raise ImportError("Please install the `requests` module "
                          "to use this function")

    # Make the request
    results = []

    for url in urls:
        response = requests.get(BASE_URL+SHORTEN_PATH,
                                params={"action": "shorten",
                                        "url": url,
                                        "key": key})

        if response.status_code != 200:
            raise ValueError("Expected 200, got {}\n{}".format(
                response.status_code, response.text))

        path = response.text.split("/")[-1]
        if verbose:
            results.append({
                base: base+path
                for base in SHORTEN_BASES
            })
        else:
            results.append(SHORTEN_STANDARD + path)

    return results


class Client:
    """
    In case you want to make multiple requests
    without constantly passing `api_key` and/or `loop`
    """

    def __init__(self, api_key, **kwargs):
        self.key = api_key
        self.loop = kwargs.get("loop", None)
        self.verbose = kwargs.get("verbose", False)

    def toggle_verbose(self):
        self.verbose = not self.verbose

    def upload_files(self, *files):
        return upload_files(self.key, *files, verbose=self.verbose)

    def shorten_urls(self, *urls):
        return shorten_urls(self.key, *urls, verbose=self.verbose)


if PY_VERSION == 3:
    from . import async_owo

    class Client(async_owo.Client, Client):
        pass

    async_upload_files = async_owo.async_upload_files
    async_shorten_urls = async_owo.async_shorten_urls



#!/data/data/com.termux/files/usr/bin/env python3.5

"""
Used to fix termux shebangs
"""

import os


def main():
    os.system("termux-fix-shebang /data/data/com.termux/files/usr/bin/owo")
    os.system("termux-fix-shebang /data/data/com.termux/files/usr/bin/owo-bg")


if __name__ == '__main__':
    main()



from setuptools import setup, find_packages
from os import path

here = path.abspath(path.dirname(__file__))

with open('README.md') as f:
    long_description = f.read()

setup(
    name='owo',

    version='2.2.0',

    description='Python API wrapper for api.awau.moe',
    long_description=long_description,

    url='https://github.com/whats-this/owo.py',

    author='martmists',
    author_email='martmists@gmail.com',

    license='MIT',

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Communications :: File Sharing',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3.5',
    ],
    install_requires=[
		"requests"
	],
    packages=find_packages(),

    entry_points = {
        'console_scripts': ['owo=owo.cli:main', 'owo-bg=owo.bg:main', 
                            'owo-fix=owo.fix_termux:main'],
    },
    keywords='api wrapper owo',
)


#!/usr/bin/env python3.5

"""
owo.py background process
main use intended for mobile devices
usage: `$ owo-bg -p path -k API_KEY`
"""

from __future__ import print_function

import argparse
import owo
import os
import sys
import time
import shlex
import subprocess


def print_v(text):
    if args.verbose:
        print(text)


parser = argparse.ArgumentParser()
parser.add_argument("-k", "--key", help="API Key", required=True)

parser.add_argument("-p", "--path", help="Path to check file updates",
                    default="/sdcard/pictures/screenshots/")

parser.add_argument("-u", "--url", help="Base vanity url to use",
                    default="https://owo.whats-th.is/")

parser.add_argument("-v", "--verbose", help="Increase output verbosity",
                    action="store_true")

# Mobile-only args
parser.add_argument("-tts", help=" Confirm message over tts | Mobile only",
                    action="store_true")

args = parser.parse_args()

sent_files = os.listdir(args.path)


def main():
    if not args.path.endswith("/"):
        args.path += "/"

    print("Starting background process...")
    while True:
        time.sleep(2)
        new_files = [f for f in os.listdir(args.path) if
                     f not in sent_files and os.path.isfile(args.path+f)]
        if new_files == []:
            continue
        for file in new_files:
            print_v("Found file: {}".format(file))
            try:
                urls = list(owo.upload_files(args.key, args.path+file,
                                             verbose=True).values())[0]

                url = urls.get(args.url)
                if url is None:
                    print("Vanity url base {} was not found, using default"
                          .format(args.url))
                    url = urls["https://owo.whats-th.is/"]

            except ValueError as e:
                print("Upload failed:\n{}".format(e.args[0]))

                # For this we can just use try:except
                try:
                    if args.tts:
                        os.system('termux-tts-speak "Upload failed"')
                    else:
                        os.system('termux-toast "Upload failed"')
                except:
                    pass

            except OverflowError:
                print("File too big: {}".format(file))

                # For this we can just use try:except
                try:
                    if args.tts:
                        os.system('termux-tts-speak "Upload too big"')
                    else:
                        os.system('termux-toast "Upload too big"')
                except:
                    pass
                sent_files.append(file)

            else:
                print_v("Upload successful.")
                sent_files.append(file)
                if (sys.executable ==
                        "/data/data/com.termux/files/usr/bin/python"):
                    # Mobile devices

                    try:
                        # os.system won't raise an error
                        subprocess.run(
                            shlex.split((
                                "termux-notification "
                                '--title "File uploaded" '
                                '--content "{0}" '
                                '--button1 "Copy link" '
                                '--button1-action "termux-clipboard-set {0}" '
                                '--button2 "Share" '
                                '--button2-action "termux-open \"{0}\"" '
                            ).format(url))
                        )

                        if args.tts:
                            # We don't need a try:catch for this
                            os.system('termux-tts-speak "Upload success"')
                        else:
                            os.system('termux-toast "Upload success"')

                        print_v("Sent notification")
                    except FileNotFoundError:
                        # termux-api not installed
                        print("File uploaded: {}, URL: {}".format(
                            file, url))
                else:
                    # Non-mobile devices
                    print("File uploaded: {}, URL: {}".format(
                        file, url))


if __name__ == "__main__":
    main()